\def\PackageName{article-arima}
\def\PackageVersion{1.0}
\def\firstversion{28/03/2003}
\def\filedate{30/05/2003}
\def\docdate{22/06/2003}


%%% Prlude %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%=== Identification Part

\NeedsTeXFormat{LaTeX2e}

\def\fileversion{\PackageVersion}
\ProvidesClass{\PackageName}[
     \filedate \space Version:\space \PackageVersion \space ]
\typeout{style Latex2e pour les articles de revue Arima, d'apres le style pour les revues ou actes Hermes de Roger Rousseau}
\ProvidesFile{\PackageName.cls}[\filedate \space Version:\space \PackageVersion]



% Dfinition des variables d'option et leur valeur par dfaut
% Les tests if ne comportent pas de `@' pour pouvoir tre utilis dans les documents
% En particulier \iftreatise peut tre utile

\newif\iffrenchlang   \frenchlangtrue    % ouvrage en franais, false => in english
\newif\ifcropmarks    \cropmarksfalse    % affichage du contour de page et de corps du texte
\newif\ifemptyheaders \emptyheadersfalse % aucun entte de page, mais numrotation hors cadre
\newif\iffirstbreak   \firstbreaktrue    % true => saut de page sur la page de titre
\newif\iffleqn        \fleqnfalse        % true => formules mathmatiques  gauche, sinon centres

%=== Declaration of options

\DeclareOption{english}{%
   \typeout{article-arima.cls : ``english'' option}%
   \frenchlangfalse
}

\DeclareOption{fleqn}{%
    \typeout{article-arima.cls : ``fleqn'' option}%
    \PassOptionsToClass{fleqn}{article}%
    \fleqntrue%
}

\DeclareOption{cropmarks}{%
   \typeout{article-arima.cls : ``cropmarks'' option}%
   \cropmarkstrue%
}


\DeclareOption*{\typeout{*** Option ``\CurrentOption'' inconnue ***\\
Syntaxe : documentclass[fleqn,english,cropmarks]{article-arima}}}
\PassOptionsToClass{10pt,twoside}{article}

%=== Execution of options

\ExecuteOptions{10pt}         % Defaults options
\ProcessOptions               % valuation des dclarations d'options

%=== Package loading

\LoadClass{article}
\RequirePackage{ifthen}
\RequirePackage{fancyhdr}
\RequirePackage{epsfig}
\RequirePackage[frenchb,english]{babel}

% Attention ! avec babel, tout appel  \selectlanguage active un espacement spcial pour
% les listes et redfinit les noms de certaines entits (tablename, figurename.... 
\let\ORIselectlanguage\selectlanguage
\gdef\selectlanguage#1{\ORIselectlanguage{#1}\@mkarima}
\def\french{\selectlanguage{frenchb}\@mkarima}
\def\english{\selectlanguage{english}\@mkarima}

%=== Packages Options as variables


%%% Fin du prlude

%%% Code des Commandes %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% <Prsentation> ---------------------------------------------------------

% Polices du corps du texte

% L'encodage recommand est T1, notamment pour les guillemets franais
% Mais certaines installations n'acceptent pas cet encodage ou ncessitent
% trop de constructions de polices pour dvips ou xdvi : je ne l'impose pas
% Il semble que les guillemets franais puissent tre obtenus par
% \leftguillemets \rightguillemets mme sans l'encodage T1.
% En cas de problme avec certains caractres pour certaines polices
% forcer l'encodage  T1 ou OT1 OU SUPPRIMER cet encodage.
% - soit ici,
      \usepackage[T1]{fontenc}
      \usepackage[latin1]{inputenc}%
% - soit dans le prlude du document, par exemple avec \usepackage[T1]{fontenc}

% Latex/Unix: Times romain 
\renewcommand{\rmdefault}{ptm}  % Postscript Times
\renewcommand{\sfdefault}{phv}  % Postscript Helvetica
\renewcommand{\ttdefault}{cmtt} % Police Latex tt : plus jolie et troite,


%%%% Fonte du corps de texte 
\newcommand{\FonteTexte}{\normalfont\fontsize{10}{12}\selectfont}% Police du texte normal

\newlength{\interligne}       % Ne change pas dans ce style: quand on parle
\setlength{\interligne}{12pt} % d'une ligne blanche, c'est a : 4.22mm
% On peut utiliser cette commande dans le texte, par exemple
% \setlength{\baselineskip}{1\interligne} pour revenir  l'espacement normal
\newcommand{\@espace}{\hspace*{0.5em}}  
                                        

% <Format> --------------------------------------------------------------

% Format des pages (pour papier a4 ou letter)
% Rappel : A4 = 210mm x 297 mm USLETTER = 8.5in x 11in = 215.9mm * 279.4mm
% soit USLETTER = 6mm de plus dans la marge droite et 17.6mm de moins dans le bas de page
\setlength{\textwidth}{125mm}   
%\setlength{\textheight}{175mm} 
\setlength{\textheight}{205mm} 

% <Marges et Format> ---------------------------------------------------

%--- Dimensions horizontales

%--- Trac du cadre indiquant les bords du papier une fois l'article massicot

% Ce trac est obtenu par l'option \documentclass[cropmarks]{article-arima}
% (par dfaut pas de trac) et est command  partir de l'en-tte (picture).
% L'avantage de ce systme est de ne pas influencer la mise en page de Latex

%-- Commandes utilisateur
\newcommand{\CropMarksOn}{\renewcommand{\@DrawPageFrame}{\@PageFrame}}
\newcommand{\CropMarksOff}{\renewcommand{\@DrawPageFrame}{}}

%-- Primitives internes
\newcommand{\@DrawPageFrame}{}
\newcommand{\@PageFrame}{%
   \thinlines%
   \setlength{\unitlength}{1mm}%
   \begin{picture}(0,0)%
%%% Tour de la page
   \put(-22.5,22.5){\line(1,0){170}}    
   \put(-22.5,22.5){\line(0,-1){240}}   
   \put(147.5,22.5){\line(0,-1){240}}   
   \put(-22.5,-217.5){\line(1,0){170}}  

%%% Tour du texte
   \put(0,-7.5){\line(1,0){125}}      
   \put(0,-182.5){\line(1,0){125}}    
   \put(0,-7.5){\line(0,-1){175}}     
   \put(125,-7.5){\line(0,-1){175}}   
   \end{picture}%
}%
\ifcropmarks
   \CropMarksOn
\else
   \CropMarksOff
\fi

\flushbottom


\newcommand{\@FonteEntete}{\sffamily\fontsize{8}{10}}


%--- Dfinition du style des autres pages

\newcommand{\ps@otherpage}{%
\setlength{\hoffset}{-1in}            
\setlength{\oddsidemargin}{42.5mm}      
\setlength{\evensidemargin}{42.5mm}     
 
%--- Dimensions verticales
\setlength{\voffset}{-1in}    
\setlength{\topmargin}{48.5mm}  % distance bord sup feuille au haut de l'en-tte
\settoheight{\headheight}{10mm} % Hauteur de l'en-tete
\setlength{\headsep}{7.5mm}     % 
\setlength{\topskip}{0mm}
\setlength{\footskip}{10mm}
\setlength{\parskip}{4pt}



   \ifemptyheaders
      \setlength{\footskip}{40mm} 
      \renewcommand{\@evenhead}{\parbox{\textwidth}{\@DrawPageFrame}}%
      \renewcommand{\@oddhead}{\parbox{\textwidth}{\@DrawPageFrame}}%
      \renewcommand{\@evenfoot}{\@FonteEntete\thepage \hspace*{\fill}}%
      \renewcommand{\@oddfoot}{\hspace*{\fill}\@FonteEntete \thepage}%
   \else
      \renewcommand{\@evenhead}{%
         \parbox{\textwidth}{%
             \@DrawPageFrame\@FonteEntete\FonteEnTete{\thepage}\hspace{\@ESPage}\VAR@EnTeteG}}%
      \renewcommand{\@oddhead}{%
         \parbox{\textwidth}{%
             \@DrawPageFrame\hspace*{\fill}\@FonteEntete\VAR@EnTeteD%
             \hspace{\@ESPage}\FonteEnTete{\thepage}}}%
      \renewcommand{\@evenfoot}{\parbox{\textwidth}{%
      \@FonteEntete\sffamily\bfseries\flushleft\fontsize{8}{10}\VAR@NomRevue}}%
      \renewcommand{\@oddfoot}{\parbox{\textwidth}{%
      \@FonteEntete\sffamily\bfseries\flushright\fontsize{8}{10}\VAR@NomRevue}}%
   \fi
}% otherpage style

\pagestyle{otherpage}% doit tre plac aprs les dfinitions prcdentes

% <En-tte> -----------------------------------------------------------
\newcommand{\FonteEnTete}{\sffamily\fontsize{8}{12}\selectfont}% Police des en-ttes
\newcommand{\VAR@EnTeteG}{%
  \FonteEnTete%
  Nom de la revue ou confrence ( dfinir par \texttt{\@BS submitted ou \@BS toappear})}
\newcommand{\VAR@EnTeteD}{%
  \FonteEnTete%
  Titre abrg de l'article ( dfinir par \texttt{\@BS title[titre abrg]\{titre\}})}

% <Titres et sous-titres> -------------------------------------------------

% <Premire page de l'article> ------------------------------------------

\newcommand{\nofirstpagebreak}{\firstbreakfalse}
\newcommand{\firstpagebreak}{\firstbreaktrue}
\newcommand{\insertbandeau}{\setlength{\intextsep}{5pt}\begin{figure}[h]\includegraphics{bandeau.eps}\end{figure}}
\renewcommand{\headrulewidth}{0pt}
\newcommand{\maketitlepage}{%

   \setlength{\parskip}{0pt}%
   \setlength{\parindent}{0pt}%
   \setlength{\hoffset}{-1in}     
\setlength{\oddsidemargin}{42.5mm}
\setlength{\evensidemargin}{42.5mm} 
    \setlength{\voffset}{-1in}
    \setlength{\topmargin}{15mm}
    \setlength{\textheight}{205mm}
    \setlength{\headheight}{121.99379pt}
    \setlength{\headsep}{8mm}
    \setlength{\footskip}{37mm} % dist. bas du texte au bas du pied de page.
    \@DrawPageFrame    
    \thispagestyle{empty}
   \thispagestyle{fancy}%
   {% Block 1\iere page
\lhead{
\setlength{\parindent}{-6.7pt}
\begin{tabular}{l}
\includegraphics{bandeau2.eps}
\end{tabular}
}
\lfoot{
\setlength{\parindent}{-6.7pt}
%\begin{tabular}{c}
%\FonteEnTete\sffamily\hfill Volume~\VAR@VolumeRevue~~--~~\VAR@AnneeRevue\VAR@Pages~--~\VAR@NomRevue  \\
%\\
%\includegraphics*{bandeau2.eps}
%\end{tabular}
}
\cfoot{}
\rfoot{}


\ifthenelse{\boolean{isrubrique}}{\vspace{6mm} \hfill\VAR@rubrique}{\vspace{1mm}}

   \@Titre{\VAR@title}
   \@SousTitre{\VAR@subtitle}
   \@Auteurs{\VAR@author}
   \par\vspace*{1\interligne}
   \@Adresse{\VAR@address}
   \vspace*{4pt}
     \ifthenelse{\boolean{issubtitle}}{ 
   \vspace*{4pt}}{\vspace{5pt}}

   \insertbandeau
   \iffrenchlang
      \@Resume{\VAR@resume}%
      \par\vspace*{4pt}%
      \@Abstract{\VAR@abstract}%
      \par\vspace*{4pt}%
      \@MotsCles{\VAR@motscles}%
      \par\vspace*{4pt}%
      \@KeyWords{\VAR@keywords}%
    \else
      \@Abstract{\VAR@abstract}%
      \par\vspace*{4pt}%
      \@Resume{\VAR@resume}%
      \par\vspace*{4pt}%
      \@KeyWords{\VAR@keywords}%
      \par\vspace*{4pt}%
      \@MotsCles{\VAR@motscles}%
   \fi
   \vspace{1mm}
   \insertbandeau

   \setcounter{section}{0}%
   \setcounter{footnote}{0}%
   }%
   \iffirstbreak
      \par\vspace*{\stretch{3}}\newpage%
   \else
      \par\vspace*{1\interligne}
   \fi
   % Pour viter les interfrences avec d'autres packages, il vaut mieux dfinir 
   % les constantes suivantes aprs \begin{document}, par exemple ici.
   \setlength{\parindent}{5mm} % renfoncement (ou retrait)
   
}%\maketitlepage

\renewcommand{\maketitle}{\maketitlepage}


% <Titre et sous-titre> ------------------------------------------------------
\renewcommand{\title}[2][]{
%usage: \title[shorttitle]{title}
   \ifthenelse{\equal{#1}{}}{%Y
      \@shorttitle{#2}%
   }{%
      \@shorttitle{#1}%
   }
   \renewcommand{\VAR@title}{#2}
}

%--- titre Courant (ou abrg) pour les en-ttes de pages impaires

\newcommand{\VAR@TitreAbrege}{Titre abrg : %
              dfinir par \texttt{\@backslashchar shorttitle\{...\}}}
\newsavebox{\@shtitle}
\newcommand{\@shorttitle}[1]{%
   % #1: Titre abrg de l'article 
   % test de la largeur < 65mm
   \sbox{\@shtitle}{\@FonteEntete #1}%
    \ifthenelse{\lengthtest{\wd\@shtitle > 65mm}}{%
     \@latex@error{short title defined by \@backslashchar title[short]{long} too long:
       (65mm max)}\@eha
    }{}
   \renewcommand{\VAR@TitreAbrege}{#1}
}

\def\subtitle#1{\renewcommand{\VAR@subtitle}{#1}}
\def\author#1{\renewcommand{\VAR@author}{#1}}
\def\address#1{\renewcommand{\VAR@address}{#1}}
\def\abstract#1{\renewcommand{\VAR@abstract}{#1}}
\def\motscles#1{\renewcommand{\VAR@motscles}{#1}}
\def\keywords#1{\renewcommand{\VAR@keywords}{#1}}
\def\resume#1{\renewcommand{\VAR@resume}{#1}}


%-- Primitives internes
\def\@BS{\symbol{"5C}}
\def\@ARGS{\{\ldots\}}
\def\@ARG#1{\{\normalfont\textit{#1}\}}


%--- Signature et en-ttes de l'article : 

\newcommand{\FonteSignature}{\normalfont\fontsize{9pt}{10.8pt}\selectfont}
\newcommand{\FonteRubrique}{%
   \sffamily \fontsize{10pt}{12pt}\selectfont
   }
\newcommand{\VAR@rubrique}{}
\newcommand{\VAR@SignatureArticle}{}
\newcommand{\VAR@NomRevue}{}
\newcommand{\VAR@VolumeRevue}{}
\newcommand{\VAR@NumeroRevue}{}
\newcommand{\VAR@AnneeRevue}{}
\newlength{\@ESPage}\setlength{\@ESPage}{4mm}% 5 espaces blancs
\newcommand{\VAR@Pages}{}
\newcommand{\VAR@NumeroSoumission}{}
\newcommand{\VAR@NomActes}{}
\newcommand{\journal}[7][]{% pour article de revue
   % #1 [rubrique]
   % #2 {revue}
   % #3 {vol}
   % #4 {num}
   % #5 {annee}
   % #6 {1ere p.}
   % #7 {dern. page}
\newboolean{isrubrique}
\newboolean{issubtitle}
   \renewcommand{\VAR@rubrique}{\FonteRubrique#1}
   \renewcommand{\VAR@NomRevue}{#2}
   \renewcommand{\VAR@VolumeRevue}{#3}
   \renewcommand{\VAR@NumeroRevue}{#4}
   \renewcommand{\VAR@AnneeRevue}{#5}
   \renewcommand{\VAR@Pages}{#6}
   

        \ifthenelse{\equal{\VAR@Pages}{-}}{%1re page inconnue
      \setcounter{page}{1}
      \setlength{\@ESPage}{6mm}
      \renewcommand{\VAR@Pages}{}
   }{%1ere page donne
      \setcounter{page}{#6}
      \renewcommand{\VAR@Pages}{,~pages~#6\ \`a~#7}
   }

        \renewcommand{\VAR@EnTeteG}{\FonteEnTete\VAR@NomRevue %
            ~--~Volume~\VAR@VolumeRevue~--~\VAR@AnneeRevue}
   \renewcommand{\VAR@EnTeteD}{\FonteEnTete\VAR@TitreAbrege}
   }

%\journal
 
%%% Nom prdfini de revue
\newcommand{\arima}{A~R~I~M~A}

%--- Titre de l'article

\newcommand{\VAR@title}{Titre de l'article%
   {\par\renewcommand{\baselinestretch}{0.66}\par\FonteTexte%@@
    \textit{A dfinir par la commande 
    \texttt{\upshape\@BS title[} titre abrg \texttt{\upshape]\{} titre complet \texttt{\upshape\}}
    sur une ou deux lignes coupes par \@BS\@BS.\\
    Le sous-titre ventuel est dfini sur une ou deux lignes par la commande\\
    \texttt{\upshape\@BS subtitle\{} sous-titre complet \texttt{\upshape\}}.}}}

\newcommand{\FonteTitre}{%%%% 16 points interlign 20pt 
   \flushright\sffamily\bfseries\fontsize{16}{20}\selectfont}

\newcommand{\@Titre}[1]{{%
   % #1: Titre complet de l'article (peut incorporer des `\\')
   \FonteTitre #1%
   \par\vspace*{15pt}% 
}}

%--- Sous-Titre de l'article
\newcommand{\VAR@subtitle}{}

\newcommand{\FonteSousTitre}{%%%% 13pt interlign 16pt
   \raggedleft\sffamily\bfseries\fontsize{13}{16}\selectfont}

\newcommand{\@SousTitre}[1]{{%
   % #1: Sous-titre de l'article dans une police plus petite (peut incorporer des `\\')
   \setlength{\parskip}{0pt}%
   \FonteSousTitre #1%
   \par\vspace*{15pt}
}}
%--- Auteurs

\newcommand{\FonteAuteur}{%%%% 12pt interlign 14pt 
    \rmfamily\upshape\fontsize{12}{14}\selectfont}

\newcommand{\VAR@author}{%
   Auteur(s)\\
   {\FonteTexte\textit{A dfinir par la commande \texttt{\upshape\@BS author\@ARGS}.
    Dans le cas de plusieurs auteurs, sparer chaque auteur par 
    \texttt{\upshape\@BS andauthor}.
    Dans le cas d'adresses diffrentes des auteurs, indexer chaque auteur avec des
   astrisques comme \fup{*} ou \fup{**} obtenues par 
  \texttt{\upshape\@BS fup\{*\}} ou \texttt{\upshape\@BS fup\{**\}}.
}}}

\newcommand{\@Auteurs}[1]{{%
    \FonteAuteur #1%
}}

\newcommand{\andauthor}{%
   % Tiret long maigre de sparation entre deux noms d'auteurs
   {\FonteTexte\mdseries --- }}

%--- Adresse(s) de(s) auteur(s)
\newcommand{\FonteAdresse}{\rmfamily\mdseries\fontsize{9}{11}\selectfont}

\newcommand{\VAR@address}{Adresse :\\
   {\FonteTexte\textit A dfinir sur plusieurs lignes par la commande 
    \texttt{\upshape\@BS address\@ARGS}.\\
    Email sur la dernire ligne.\\
    Dans le cas d'adresses diffrentes des auteurs, indexer chaque auteur avec des
   astrisques comme \fup{*} ou \fup{**} obtenues par 
  \texttt{\upshape\@BS fup\{*\}} ou \texttt{\upshape\@BS fup\{**\}}.\\
   Voir aussi <<~Consignes aux auteurs~>>
}}

\newcommand{\@Adresse}[1]{\FonteAdresse #1}

%--- Rsum et Abstract
\newcommand{\FonteResume}{\sffamily\mdseries\fontsize{8}{11}\selectfont}

\newcommand{\FonteTitreResume}{%
   \sffamily\bfseries\fontsize{8}{11}\selectfont}

\newcommand{\VAR@resume}{%
   {\FonteTexte\textit{A dfinir par la commande \texttt{\upshape\@BS resume\@ARGS}}}}

\newcommand{\@TitreResume}[2]{\FonteTitreResume \noindent #1#2\FonteResume}

\newcommand{\@Resume}[1]{{\french\@TitreResume{RSUM}{.} #1}}

%--- Abstract

\newcommand{\VAR@abstract}{%
   {\FonteTexte\textit{A dfinir par la commande \texttt{\upshape\@BS abstract\@ARGS}}}}

\newcommand{\@Abstract}[1]{{\english\@TitreResume{ABSTRACT}{.} #1}}

%--- Mots-cls

\newcommand{\VAR@motscles}{%
   {\FonteTexte\textit{A dfinir par la commande \texttt{\upshape\@BS motscles\@ARGS}}}}

\newcommand{\@MotsCles}[1]{{\french\@TitreResume{MOTS-CLS}{~:} #1}}

%--- Keyswords

\newcommand{\VAR@keywords}{%
   {\FonteTexte\textit{A dfinir par la commande \texttt{\upshape\@BS keywords\@ARGS}}}}

\newcommand{\@KeyWords}[1]{{\english\@TitreResume{KEYWORDS}{~:} #1}}

% <Titre des paragraphes ou titre d' inter  (sections)>----------------

% On numrote jusqu' la section de niveau 4
\setcounter{secnumdepth}{4}

% Pour les titres de section sur plusieurs lignes, pas d'indentation
\def\@hangfrom#1{%
       \setbox\@tempboxa\hbox{{#1}}%
%       \hangindent \wd\@tempboxa\noindent\box\@tempboxa %% ORIGINAL de latex.ltx
       \hangindent \wd 0 \noindent\box\@tempboxa %% MODIF
}
%--- Niveau 1: section
 
\newcommand{\FonteSectionI}{\sffamily\bfseries\raggedright\fontsize{12}{16}\selectfont}%

\renewcommand{\thesection}{\arabic{section}}%
\renewcommand{\section}{%
   \par\vspace{20pt}
   \hrule height 0.5mm
   \vspace{1mm}
   \renewcommand{\@seccntformat}[1]{\fontsize{12}{16}\thesection.\hspace{0.5em}}
   \@startsection{section}  % nom de l'inter
   {1}%                     % niveau de l'inter
   {0pt}%                   % l'indentation du titre et du texte suivant
   {4pt}% beforeskip %
   {6pt}% afterskip
   {\FonteSectionI}%        % style
}

%--- Niveau 2: sous-section
\newcommand{\FonteSectionII}{\sffamily\bfseries\raggedright\fontsize{11}{14}\selectfont}%

\renewcommand{\thesubsection}{\thesection.\arabic{subsection}}%
\renewcommand{\subsection}{%
\vspace{2mm}
  \renewcommand{\@seccntformat}[1]%
               {{\fontsize{12}{16}\thesubsection.\hspace{0.5em}}}%
  \@startsection%
   {subsection}%            % nom de l'inter
   {2}%                     % niveau de l'inter
   {0pt}%                   % l'indentation du titre et du texte suivant
   {3pt}
   {5pt}
   {\FonteSectionII}}%      % style

%--- Niveau 3: sous-sous-section 

\newcommand{\FonteSectionIII}{\sffamily\bfseries\fontsize{10}{13}\raggedright\selectfont}%

\renewcommand{\thesubsubsection}{\thesubsection.\arabic{subsubsection}}%
\renewcommand{\subsubsection}{%
  \renewcommand{\@seccntformat}[1]{%
               {\sffamily\bfseries\fontsize{10}{13}\thesubsubsection.\hspace{0.5em}}}%
  \@startsection%
   {subsubsection}%         % nom de l'inter
   {3}%                     % niveau de l'inter
   {0pt}%                   % l'indentation du titre et du texte suivant
   {3pt}
   {3pt}
   {\FonteSectionIII}}%     % style


%--- Niveau 4: paragraphes 
\newcommand{\FonteSectionIV}{\sffamily\fontsize{10}{13}\raggedright\selectfont}%

\renewcommand{\theparagraph}{\thesubsubsection.\arabic{paragraph}}%
\renewcommand{\paragraph}{%
  \renewcommand{\@seccntformat}[1]{%
               {\sffamily\fontsize{10}{13}\theparagraph.\hspace{0.5em}}}%
  \@startsection%
   {paragraph}%             % nom de l'inter
   {4}%                     % niveau de l'inter
   {0mm}%                   % l'indentation du titre et du texte suivant
   {8pt}
   {10pt}
   {\FonteSectionIV}}%      % style

% <Alinas>----------------------------------------------------------------

% Disable single lines at the start of a paragraph
\clubpenalty = 10000
% Disable single lines at the end of a paragraph 
\widowpenalty = 10000
\displaywidowpenalty = 10000

% <Notes de bas de page> --------------------------------------------------

\newcommand{\FonteNoteBasPage}{\fontsize{8}{11}\sffamily}
\renewcommand{\footnotesize}{\FonteNoteBasPage}
\addtolength{\skip\footins}{6pt} 

\renewcommand{\footnoterule}{%
\par\vspace*{-12.3pt}
\noindent\rule{2.5cm}{0.3pt}\vspace*{6pt} 
}

\setlength{\footnotesep}{3pt} % Espace vertical avant chaque note (strut)

\newcommand{\@Myfnmark}{
      \mbox{\fontsize{8}{11}\sffamily\arabic{footnote}. }%
}

\renewcommand{\@makefntext}[1]{%
      \noindent\@Myfnmark#1%
}%

\def\@thefnmark{\arabic{footnote}}

% <Objets flottants: figures, tableaux et programmes> -------------------------------

% Correction du bug du style french qui redfinit le corps des lgendes par \em
% et non \itshape (gnant si l'utilisateur redfinit \em).

% Le plus fiable est de redfinir \@caption de latex.ltx qui est l'unique appel
%  \@makecaption (En esprant que \@caption ne sera pas redfini dans latex).
\long\def\@caption#1[#2]#3{{\setlength{\parskip}{0pt}\par\addcontentsline{\csname
   ext@#1\endcsname}{#1}{\protect\numberline{\csname
   the#1\endcsname}{\ignorespaces #2}}\begingroup
     \@parboxrestore
     \normalsize
     \@Mymakecaption{\csname fnum@#1\endcsname}{\ignorespaces #3}\par
   \endgroup}}
\newcommand{\FonteTitreLegende}{\sffamily\mdseries\fontsize{9}{11}\itshape}
\newcommand{\FonteCaptionName}{\sffamily\fontsize{9}{11}\bfseries}

\newcommand{\@Mymakecaption}[2]{{%
   \setlength{\parskip}{0pt}%
   \par\vspace{1\interligne}
   \noindent\parbox[t]{\linewidth}{\FonteCaptionName #1.\hspace{3pt}%
                       \FonteTitreLegende #2}
}}

\newcommand{\topfigrule}{}               % cmde de trac 1 rgle float haut et texte
\newcommand{\botfigrule}{}               % cmde de trac 1 rgle float bas et texte


\setcounter{topnumber}{1}              % df. 2    % nb max de fig. en haut
\setcounter{bottomnumber}{1}           % df. 1    % nb max de fig. en bas
\setcounter{totalnumber}{2}            % df. 3    % nb max de fig. par page
\renewcommand{\topfraction}{1}         % df. 0.7  % fraction max de remplissage de la
                                                   % page par la (les) figure(s) en haut
\renewcommand{\bottomfraction}{1}      % df. 0.3  % fraction max de remplissage de la
                                                   % page par la figure en bas
                                                   % en baspar fig
\renewcommand{\textfraction}{0}        % df. 0.2  % fract. min remplissage texte / page
\renewcommand{\floatpagefraction}{0.8} % df. 0.5  % remplissage floatpage

% Dimensions des espaces verticaux lastiques autour des figures :
% jouent un rle important pour le placement, on a intrt  augmenter l'lasticit
\setlength{\floatsep}{12pt} 
                           % par dfaut: \setlength{\floatsep}{12pt plus 2pt minus 2pt}
\setlength{\textfloatsep}{0pt}
                                                   % pour des figures en haut ou en bas
                        % par dfaut: \setlength{\textfloatsep}{20pt plus 2pt minus 4pt}
\setlength{\intextsep}{10pt} % espace supplmentaire au dessus et 
                        % en dessous d'une figure [h], entre figure et texte.
                        % par dfaut: \setlength{\intextsep}{\floatsep}

%%%---<Formules>

% En mode standard, les modes equation, eqnarray et eqnarray*
% fournissent bien une ligne blanche au dessus et au dessous et la numerotation
% colle sur la marge de droite.
% La seule adadaptation est la numrotation [n] au lieu de (n).
\renewcommand{\@eqnnum}{\reset@font\rmfamily [\theequation]}

% Dfinition des espaces avec l'option fleqn :
% L'option fleqn (\documentclass[fleqn]...) place les formules indentes 
% gauche. Par dfaut, les formules sont centres.

\iffleqn
    \setlength{\topsep}{1\baselineskip}  % espace supplm. au dessus/dessous des formules.
    \setlength{\mathindent}{20mm}        % indentation des formules
\fi

% Dfinition des espaces sans l'option fleqn :

\setlength{\jot}{0.5\baselineskip}      % espace entre les lignes de eqnarray
\setlength{\abovedisplayskip}{0mm}      % espace supplmentaire au dessus des longues formules
\setlength{\abovedisplayshortskip}{0mm} % idem, formules courtes
\setlength{\belowdisplayskip}{0mm}      % espace supplmentaire au dessous des longues formules
\setlength{\belowdisplayshortskip}{0mm} % idem, formules courtes

%--- Utilitaires facultatifs

% Utiliser la commande \eqncont pour terminer une ligne de formule
% sur plusieurs lignes : supprime la numrotation + espace vertical plus serr.
\newcommand{\eqncont}{\nonumber \\(0\baselineskip)}

%%% Retardement du pagebreak

%  Pour retarder le passage automatique  la page suivante de 1 ou 2 lignes,
%  utiliser le couple de commandes \delaynewpage{nb lignes} ... \forcenewpage
%  Attention! cette technique est du bricolage, mais cependant indispensable
%  pour une prsentation optimale d'un document. (indique par Lamport).
%  IL NE FAUT L'EMPLOYER QUE TOUT  LA FIN, JUSTE AVANT L'IMPRESSION FINALE.
%  En principe ne pas retarder de plus de 2 lignes !

\newcommand{\delaynewpage}[1]{\enlargethispage{#1\baselineskip}}
   %  utiliser sur la page  allonger,  un endroit bien visible
   % avant le premier paragraphe ou la figure  faire tenir sur la page.
   % Provoque une descente des notes de bas de page s'il y en a !

\newcommand{\forcenewpage}{\pagebreak\noindent}
   %  utiliser  l'endroit prcis o la coupure doit tre force.
   % on peut placer cette commande en dbut de ligne, avec suite du texte
   % sur la ligne suivante pour faciliter son reprage

% Listes --------------------------------------------------------------------------------------------------

% Espaces communs aux listes numrotes (enumerate) ou non (itemize)
% Attention !!! Ces espacements ne peuvent tre efectifs que si Babel ne les redfinit
% pas dans \@trivlist, comme il tente de l'imposer. Il faut ABSOLUMENT
% excuter \bbl@nonfrenchlistspacing avant le dbut du document (\AtBeginDocument).

\def\mkarimalist{%
   \gdef\itemize{\arimaitemize}\gdef\enditemize{\endarimaitemize}%
   \gdef\enumerate{\arimaenumerate}\gdef\endenumerate{\endarimaenumerate}%
}

\newcommand{\ArimaItemizeSpacing}{%
% espacements horizontaux
   \leftmargin=0pt
   \labelsep=1mm
   \ifnum \@itemdepth < 2  % niveau 0 ou 1
      \setlength{\itemindent}{\itemindenti}
      \listparindent=5mm
   \else                   % niveau 2
      \itemindent=\itemindentii
      \listparindent=5mm
   \fi
   \labelwidth=0pt
   \rightmargin=0pt
  % espacements verticaux des listes
   \itemsep=0pt
   \topsep=0pt 
   %%%% 3pt entre les paragraphes
   \parskip=3pt
   \partopsep=0pt
   \parsep=3pt
% pnalits
   \sloppy%
   \widowpenalty4000	%ligne isole en dbut de page
   \clubpenalty4000	%ligne isole  la fin d'une page
}

\newcommand{\displaylistdimen}{
     itemdepth: \the\@itemdepth ;\\
     topsep: \the\topsep ;\\
     itemsep: \the\itemsep ;\\
     parskip: \the\parskip ;\\
     partopsep: \the\partopsep ;\\
     parsep: \the\parsep.
}

% Listes non numrotes (itemize) -------------------------------------------------------------------------

\newlength{\labelwidthi}      % largeur de la bote contenant le retrait de 5mm + tiret moyen
\settowidth{\labelwidthi}{--} % environ 2mm, tiret moyen
\addtolength{\labelwidthi}{5mm} % retrait + largeur du tiret moyen, environ 7mm

\newlength{\itemindenti}      % dcalage du texte de 1re ligne depuis marge gauche 
\setlength{\itemindenti}{\labelwidthi} % = labelwidthi
\addtolength{\itemindenti}{1mm}          %   + labelsep

\newlength{\labelwidthii}       % largeur de la bote contenant le retrait de 10mm + tiret court
\settowidth{\labelwidthii}{-}   % environ 1mm, tiret court
\addtolength{\labelwidthii}{5mm} % retrait + largeur du tiret court, environ 11mm

\newlength{\itemindentii}      % dcalage du texte de 1re ligne depuis marge gauche 
\setlength{\itemindentii}{\labelwidthii} % = labelwidthii
\addtolength{\itemindentii}{1mm}           %   + labelsep

\newenvironment{arimaitemize}{% liste  deux niveaux seulement
 \ifnum \@itemdepth > 1 \@toodeep % ici, \@itemdepth = niveau -1 
 \else%
    \renewcommand{\labelitemi}{{\makebox[\labelwidthi][r]{--}}}%
    \renewcommand{\labelitemii}{{\makebox[\labelwidthii][r]{-}}}%
    \advance\@itemdepth \@ne%
    \edef\@itemitem{labelitem\romannumeral\the\@itemdepth}%
    \begin{list}%
       {\csname\@itemitem\endcsname}%
       {\def\makelabel##1{\llap{##1}}% ##1 signifie arg 1 de list et non de arimaitemize
        % dfinir les espaces ici et nulle part ailleurs
        \ArimaItemizeSpacing %
       }%\item \displaylistdimen
 \fi}{\end{list}}%

% Listes numrotes ---------------------------------------------------------------------------------------

\newlength{\enumwidthi}      % largeur de la bote contenant le retrait de 5mm + n.
\settowidth{\enumwidthi}{5mm} % environ 2mm, chiffre le plus large
\addtolength{\enumwidthi}{5mm} % retrait + largeur du tiret moyen, environ 7mm

\newlength{\enumindenti}      % dcalage du texte de 1re ligne depuis marge gauche 
\setlength{\enumindenti}{\enumwidthi} % = enumwidthi
\addtolength{\enumindenti}{1mm}          %   + enumsep

\newlength{\enumwidthii}         % largeur de la bote contenant le retrait de 10mm + tiret court
\settowidth{\enumwidthii}{b)}   % environ 1mm, tiret court
\addtolength{\enumwidthii}{5mm} % retrait + largeur du tiret court, environ 11mm

\newlength{\enumindentii}      % dcalage du texte de 1re ligne depuis marge gauche 
\setlength{\enumindentii}{\enumwidthii} % = enumwidthii
\addtolength{\enumindentii}{1mm}           %   + enumsep

\newenvironment{arimaenumerate}{% enumration  un niveau
 \ifnum \@itemdepth >1 \@toodeep
 \else%
      \advance\@enumdepth \@ne%
      \advance\@itemdepth \@ne%
      \edef\@enumctr{enum\romannumeral\the\@enumdepth}%
      \begin{list}%
         {\csname label\@enumctr\endcsname}%
         {%
          \usecounter{\@enumctr}%
          \def\makelabel##1{\llap{##1}}% ##1 signifie arg 1 de list et non de arimaenumerate
          % dfinir les espaces horizontaux ici
          \ArimaItemizeSpacing%
          \ifnum \@itemdepth =1
             \setlength{\itemindent}{\enumindenti}
          \else
             \setlength{\itemindent}{\enumindentii}
          \fi
          \renewcommand{\labelenumi}{{\makebox[\labelwidthi][r]{\arabic{enumi})}}}
          \renewcommand{\labelenumii}{{\makebox[\labelwidthii][r]{\alph{enumii})}}}%
         }
   \fi}{\end{list}}


% Redfinition de quote pour rduire l'espace vertical  6 pts

\let\quoteORI\quote
\let\endquoteORI\endquote
\renewenvironment{quote}{%
\par\vspace{-6pt}%
\begin{quoteORI}%
}{%
\end{quoteORI}%
\par\vspace{-6pt}%
}

%<Remarques ou notes> -----------------------------------------------------

\newcommand{\remark}[1]{{\setlength{\parskip}{0pt}%
    \par\noindent\fontsize{10}{12}\textsc{\remarkname}.\ ---\ #1\\}}
\newcommand{\note}[1]{{\setlength{\parskip}{0pt}%
    \par\noindent\fontsize{10}{12}\textsc{\notename}.\ ---\ #1\\}}

%<Typographie> ------------------------------------------------------------

%<Remerciements> ---------------------------------------------------------
\newcommand{\acknowledgements}[1]{{
   \setlength{\parskip}{0pt}%
   \par\vspace{\interligne}\noindent%
   \FonteTexte \acknowledgementsname%
   \nopagebreak[4]%
   \par\vspace{1\interligne}
   #1%
}}
%<Bibliographie> ------------------------------------


\bibliographystyle{biblio-arima}%
\newcommand{\FonteBibliographie}{\rmfamily\mdseries\upshape\fontsize{9}{11}\selectfont}
\renewenvironment{thebibliography}[1]{%BEGIN
   \section{\ArimaRefname}\label{biblio}%
   \begin{BiblioArima}
  }{%END
   \end{BiblioArima}
}

% BiblioArima affiche une liste de references bibliographiques.
% Les entres sont normalement prpares par le style arima.bst, mais
% peuvent aussi s'crire  la main :
% \bibitem[ref]{cite} qui crit comme d'habitude
% la clef de citation dans le fichier .aux pour bibtex
% \bibi[ref] qui affiche seulement l'entree, sans crire sur .aux
% (utilit trs spciale, pour placer plusieurs biblios dans un document).
\def\bibi[#1]{\item[\@biblabel{#1}\hfill]} % @ special
\newenvironment{BiblioArima}{%BEGIN
   \list{}{% Dfinition des paramtres de liste pour la bibliographie Arima
         \usecounter{enumiv}%
         \let\p@enumiv\@empty
         \renewcommand\theenumiv{\arabic{enumiv}}%
         \renewcommand\newblock{\hskip .11em \@plus.33em \@minus.07em}%
         \FonteBibliographie%
         %% dimensions horizontales
         \setlength{\leftmargin}{5mm}%%%
         \setlength{\itemindent}{-3mm}%%%
         \setlength{\labelsep}{2mm}%%%
         \setlength{\labelwidth}{0mm}%%%
         %% dimensions verticales
          \setlength{\topsep}{0pt}%
          \setlength{\parskip}{6pt}%
          \setlength{\itemsep}{0pt}%
          \setlength{\partopsep}{0pt}%
          \setlength{\parsep}{3pt}%
         \sloppy\clubpenalty4000\widowpenalty4000%
         \sfcode`\.=\@m
         }%
  }{%END
      \def\@noitemerr{\@latex@warning{Empty `thebibliography' environment}}
      \FonteTexte%
      \endlist%
}

%<Biographie> ----------------------------------------------------------------------
% Il faut 2 lignes au dessus de la premire biographie et 1 ligne
% de sparation entre les biographies.

\newcommand{\@fonteBiographie}{%
   \sffamily\mdseries\itshape\fontsize{8}{11}\selectfont}
\newcommand{\@firstbiography}{yes}

\newcommand{\biography}[2]{
  % #1 = Nom de l'auteur, 
  % #2 = biographie enchane derrire le nom d'auteur, typiquement
  %       est chercheur au laboratoire... 
  \ifthenelse{\equal{\@firstbiography}{yes}}{% premire biographie
  \renewcommand{\@firstbiography}{no}%
  \par\vspace{22pt}\noindent% + 6pt de \parskip
  }{% biographies suivantes
  \par\vspace{6pt}\noindent% + 6pt de \parskip
  }%
  {\@fonteBiographie \textbf{#1} #2
}}



%%%-- Macros utilises pour le paramtrage sur le langage

%-- Macros identiques en francais et english
\def\pagename{p.~}
\def\pagesname{p.~}%@@normalement {pp.~}
\def\etalter{\ et al.}
\def\Inname{}
\def\inname{}
\def\editornames{Eds.}
\def\editorname{Ed.}
\def\Volumename{Vol.~}
\def\volumename{vol.~}
\def\notename{Note}
\def\degree{$^\circ$}%@@

% Quelques macros utiles dfinies dans french
\def\fup#1{\raisebox{0.55ex}{\protect\small #1\kern+.17em}}%
\def\fsc{\scshape}%
\def\@umer#1{$^{\mathrm #1}$\kern.2em\ignorespaces}%
\def\numero{n\@umer{o}}%
\def\numero{n\@umer{o}}%
\def\Numero{N\@umer{o}}%
\def\numeros{n\@umer{o}}%
\def\Numeros{N\@umer{o}}%
\def\fups#1{\raisebox{0.55ex}{{\scriptsize #1}}~}%
\def\ier{\fups{er}}%
\def\iere{\fups{re}}%
\def\ieme{\fups{e}}%
\def\iers{\fups{ers}}%
\def\ieres{\fups{res}}%
\def\iemes{\fups{es}}%

%-- Macros diffrentes en francais et english
% Doivent tre redfinies aprs chaque slection de langage
\def\initialisation{%
  \iffrenchlang %
%   \AutoSpaceBeforeFDP %
   \def\figurename{Figure}%
   \def\figname{figure}%
   \def\tablename{Tableau}%
   \def\tabname{tableau}%
   \def\programname{Programme}%
   \def\progname{programme}%
   \def\ArimaRefname{Bibliographie}%
   \def\andname{, }
   \def\acknowledgementsname{Remerciements}
   \def\remarkname{Remarque}
   \def\editionname{\'edition}
   \def\chaptername{chapitre}
   \def\technicalreportname{rapport}% valeur par dfaut du champ type
   \def\numbername{\numero}%{n~}
   \def\Numbername{\Numero}%{N~}
   \def\ofname{de}
   \def\guilo{~}
   \def\guilf{~}
   \def\Jan{janvier}
   \def\Feb{f\'evrier}
   \def\Mar{mars}
   \def\Apr{avril}
   \def\May{mai}
   \def\Jun{juin}
   \def\Jul{juillet}
   \def\Aug{ao\^ut}
   \def\Sep{septembre}
   \def\Oct{octobre}
   \def\Nov{novembre}
   \def\Dec{d\'ecembre}
\else
   \def\figurename{Figure}%
   \def\figname{figure}%
   \def\tablename{Table}%
   \def\tabname{table}%
   \def\programname{Program}%
   \def\progname{program}%
   \def\ArimaRefname{References}%
   \def\andname{, }
   \def\acknowledgementsname{Acknowledgements}
   \def\remarkname{Remark}
   \def\editionname{edition}
   \def\chaptername{chapter}
   \def\technicalreportname{report }% valeur par dfaut du champ type
   \def\numbername{num.~}
   \def\Numbername{Num.~}
   \def\ofname{of}
   \def\guilo{``}
   \def\guilf{''}
   \def\Jan{Jan. }
   \def\Feb{Feb. }
   \def\Mar{March }
   \def\Apr{April }
   \def\May{May }
   \def\Jun{June }
   \def\Jul{Jul. }
   \def\Aug{Aug. }
   \def\Sep{Sep. }
   \def\Oct{Oct. }
   \def\Nov{Nov. }
   \def\Dec{Dec. }
\fi
}%\initialisation

\def\@mkarima{%
   \mkarimalist
   \initialisation % dpend du langage
}

\AtBeginDocument{%
  \iffrenchlang %
      \selectlanguage{frenchb}%
  \else %
      \selectlanguage{english}%
  \fi%
}

%EOF


% Commandes spcifiques au style, avec nb d'arguments entre crochets

% \title[1]
% \subtitle[1]
% \author[1]
% \andauthor
% \fup
% \address[1]
% \abstract[1]
% \motscles[1]
% \keywords[1]
% \resume[1]
% \maketitlepage
% \nofirstpagebreak
% \firstpagebreak
%----
% \journal[7]
%----
% \acknowledgements[1]
% \biography[2]
%%% Utilitaires
% \remark[1]
% \note[1]
% \bibliography
% \CropMarksOn
% \CropMarksOff
% \eqncont
% \delaynewpage[1]
% \forcenewpage

% Commandes ou Environnements Latex redefinis

% \rmdefault
% \sfdefault
% \ttdefault
% \maketitle    % alias \maketitlepage
% \thesection
% \section
% \thesubsection
% \subsection
% \thesubsubsection
% \subsubsection
% \theparagraph
% \paragraph
% \footnotesize
% \footnoterule
% \newblock
% \renewenvironment{thebibliography}[1]  
% \renewenvironment{itemize}
% \renewenvironment{enumerate}
% \renewenvironment{figure}

% Compteurs entiers ou variables dcimales Latex redfinis

% section: 0
% page: 1
% secnumdepth: 4
% topnumber: 2            % nb max de fig. en haut
% bottomnumber: 1         % nb max de fig. en bas
% totalnumber: 3          % nb max de fig. par page
% \topfraction : 1        % fraction remplissage haut
% \bottomfraction : 1     % fraction remplissage bas
% \textfraction   : 0     % fraction remplissage texte / page
% \floatpagefraction: 0.8 % fraction remplissage floatpage

% Fontes utilisables (utilisation rare)

% \FonteTexte
% \FonteEnTete
% \FonteRubrique
% \FonteSignature
% \FonteTitre
% \FonteSousTitre
% \FonteAuteur
% \FonteResume
% \FonteTitreResume
% \FonteSectionI
% \FonteSectionII
% \FonteSectionIII
% \FonteSectionIV
% \FonteNoteBasPage
% \FonteTitreLegende
% \FonteCaptionName
% \FonteBibliographie

% Nom prdfini 

% \arima     : Revue ARIMA, chaque lettre spare par un espace.

% Variables utilisables
% \newlength{\interligne}

